@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-02 13:37:05
-@LastEditTime: 2021-09-17 17:52:36
+@LastEditTime: 2021-10-10 15:38:25
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -15,8 +15,6 @@ class IpInfoListHandler(ClientBaseHandler):
     :description: 获取ip列表
     """
     @filter_check_params("act_id")
-    @filter_check_head_sign()
-    @filter_check_params_sign()
     def get_async(self):
         """
         :description: 获取ip列表
