@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-02 11:03:56
-@LastEditTime: 2021-12-20 18:31:22
+@LastEditTime: 2021-12-30 11:42:33
 @LastEditors: HuangJianYi
 @Description: ip模块
 """
@@ -82,7 +82,23 @@ class IpInfoListHandler(ClientBaseHandler):
         page_index = int(self.get_param("page_index", 0))
         page_size = int(self.get_param("page_size", 20))
 
-        return self.response_json_success(IpBaseModel(context=self).get_ip_info_list(app_id, act_id, page_size, page_index,is_cache=False))
+        field = "*"
+        condition = ""
+        params = []
+        order_by = "sort_index desc"
+        invoke_result_data = self.business_process_executing()
+        if invoke_result_data.success == False:
+            return self.response_json_success({"data": []})
+        else:
+            if invoke_result_data.data:
+                field = invoke_result_data.data.get("field","*")
+                condition = invoke_result_data.data.get("condition","")
+                params = invoke_result_data.data.get("params",[])
+                order_by = invoke_result_data.data.get("order_by","sort_index desc")
+        page_list, total = IpBaseModel(context=self).get_ip_info_list(app_id, act_id, page_size, page_index, field, condition, params, order_by, is_cache=False)
+        ref_params = {}
+        page_info = PageInfo(page_index, page_size, total, self.business_process_executed(page_list, ref_params))
+        return self.response_json_success(page_info)
 
 
 class DeleteIpInfoHandler(ClientBaseHandler):
@@ -100,14 +116,13 @@ class DeleteIpInfoHandler(ClientBaseHandler):
         :last_editors: HuangJianYi
         """
         app_id = self.get_app_id()
-        act_id = int(self.get_param("act_id", 0))
         ip_id = int(self.get_param("ip_id", 0))
 
         invoke_result_data = self.business_process_executing()
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         ip_base_model = IpBaseModel(context=self)
-        invoke_result_data = ip_base_model.delete_ip_info(app_id, act_id, ip_id)
+        invoke_result_data = ip_base_model.delete_ip_info(app_id, ip_id)
         if invoke_result_data.success ==False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         self.create_operation_log(OperationType.delete.value, "ip_info_tb", "DeleteIpInfoHandler", None, ip_id)
@@ -134,7 +149,6 @@ class ReleaseIpInfoHandler(ClientBaseHandler):
         :last_editors: HuangJianYi
         """
         app_id = self.get_app_id()
-        act_id = int(self.get_param("act_id", 0))
         ip_id = int(self.get_param("ip_id", 0))
         is_release = int(self.get_param("is_release", 0))
 
@@ -142,7 +156,7 @@ class ReleaseIpInfoHandler(ClientBaseHandler):
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         ip_base_model = IpBaseModel(context=self)
-        invoke_result_data = ip_base_model.release_ip_info(app_id, act_id, ip_id, is_release)
+        invoke_result_data = ip_base_model.release_ip_info(app_id, ip_id, is_release)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         ref_params = {}
