@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-03 15:42:53
-@LastEditTime: 2021-11-29 16:40:13
+@LastEditTime: 2021-12-27 13:48:27
 @LastEditors: HuangJianYi
 @Description: 奖品模块
 """
@@ -11,6 +11,7 @@ from seven_cloudapp_frame.handlers.frame_base import *
 from seven_cloudapp_frame.models.act_base_model import *
 from seven_cloudapp_frame.models.prize_base_model import *
 from seven_cloudapp_frame.models.seven_model import PageInfo
+from seven_cloudapp_frame.libs.customize.oss2_helper import *
 
 
 class SaveActPrizeHandler(ClientBaseHandler):
@@ -134,6 +135,8 @@ class ActPrizeListHandler(ClientBaseHandler):
         """
         :description: 活动奖品列表
         :param app_id：应用标识
+        :param act_id：活动标识
+        :param module_id：活动模块标识
         :param prize_name：奖品名称
         :param is_del：是否回收站1是0否
         :param page_index：页索引
@@ -258,4 +261,99 @@ class ReleaseActPrizeHandler(ClientBaseHandler):
         invoke_result_data = self.business_process_executed(invoke_result_data, ref_params)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
-        return self.response_json_success()
\ No newline at end of file
+        return self.response_json_success()
+
+
+class ActPrizeExportHandler(ClientBaseHandler):
+    """
+    :description: 导出活动奖品列表
+    """
+    @filter_check_params("act_id")
+    def get_async(self):
+        """
+        :description: 导出活动奖品列表
+        :param app_id：应用标识
+        :param act_id：活动标识
+        :param module_id：活动模块标识
+        :param prize_name：奖品名称
+        :param is_del：是否回收站1是0否
+        :param page_size：页大小
+        :param page_index：页索引
+        :return 
+        :last_editors: HuangJianYi
+        """
+        app_id = self.get_app_id()
+        act_id = int(self.get_param("act_id", 0))
+        module_id = int(self.get_param("module_id", 0))
+        prize_name = self.get_param("prize_name")
+        is_del = int(self.get_param("is_del", -1))
+        page_index = int(self.get_param("page_index", 0))
+        page_size = int(self.get_param("page_size", 500))
+
+        condition = ""
+        params = []
+        order_by = "create_date desc"
+        field = "*"
+        invoke_result_data = self.business_process_executing()
+        if invoke_result_data.success == False:
+            return self.response_json_success("")
+        else:
+            condition = invoke_result_data.data["condition"] if invoke_result_data.data.__contains__("condition") else ""
+            params = invoke_result_data.data["params"] if invoke_result_data.data.__contains__("params") else []
+            order_by = invoke_result_data.data["order_by"] if invoke_result_data.data.__contains__("order_by") else "create_date desc"
+            field = invoke_result_data.data["field"] if invoke_result_data.data.__contains__("field") else "*"
+
+        prize_base_model = PrizeBaseModel(context=self)
+        act_prize_list_dict = []
+        if page_size <= 500:
+            act_prize_list_dict = prize_base_model.get_act_prize_list(app_id, act_id, module_id, prize_name, 0, is_del, page_size, page_index, order_by=order_by, condition=condition, params=params, field=field, is_cache=False).data
+        else:
+            max_page_size = 100
+            repeat_count = page_size // max_page_size  # 循环次数
+            begin_page_index = page_index * repeat_count  # 开始页码
+            for i in range(repeat_count):
+                list_dict = prize_base_model.get_act_prize_list(app_id, act_id, module_id, prize_name, 0, is_del, max_page_size, begin_page_index + i, order_by=order_by, condition=condition, params=params, field=field, is_cache=False).data
+                if len(list_dict) <= 0:
+                    break
+                act_prize_list_dict.extend(list_dict)
+        ref_params = {}
+        result_data = self.business_process_executed(act_prize_list_dict, ref_params)
+        resource_path = OSS2Helper.export_excel(result_data)
+        return self.response_json_success(resource_path)
+
+    def business_process_executed(self, result_data, ref_params):
+        """
+        :description: 执行后事件
+        :param result_data:result_data
+        :param ref_params: 关联参数
+        :return:
+        :last_editors: HuangJianYi
+        """
+        result_list = []
+        for act_prize_dict in result_data:
+            data_row = {}
+            data_row["奖品名称"] = act_prize_dict["prize_name"]
+            data_row["奖品子标题"] = act_prize_dict["prize_title"]
+            data_row["奖品图"] = act_prize_dict["prize_pic"]
+            data_row["商品ID"] = act_prize_dict["goods_id"]
+            data_row["商家编码"] = act_prize_dict["goods_code"]
+            data_row["奖品类型"] = act_prize_dict["prize_type"]
+            data_row["奖品价值"] = str(act_prize_dict["prize_price"])
+            data_row["奖品库存"] = act_prize_dict["surplus"]
+            data_row["奖品总库存"] = act_prize_dict["prize_total"]
+            if act_prize_dict["prize_type"] == 1:
+                data_row["奖品类型"] = "现货"
+            elif act_prize_dict["prize_type"] == 2:
+                data_row["奖品类型"] = "优惠券"
+            elif act_prize_dict["prize_type"] == 3:
+                data_row["奖品类型"] = "红包"
+            elif act_prize_dict["prize_type"] == 4:
+                data_row["奖品类型"] = "参与奖"
+            else:
+                data_row["奖品类型"] = "预售"
+            data_row["创建时间"] = TimeHelper.datetime_to_format_time(act_prize_dict["create_date"])
+            data_row["是否发布"] = "未发布"
+            if act_prize_dict["is_release"] == 1:
+                data_row["是否发布"] = "已发布"
+            result_list.append(data_row)
+        return result_list
\ No newline at end of file
