@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-11 09:10:33
-@LastEditTime: 2021-12-22 18:19:38
+@LastEditTime: 2021-12-28 17:27:51
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -19,11 +19,12 @@ class FrameBaseModel():
     """
     def __init__(self, context):
         self.context = context
-    
-    def lottery_algorithm_chance(self, prize_list):
+
+    def lottery_algorithm_chance(self, prize_list, field_name="chance"):
         """
         :description: 抽奖算法（概率）
         :param prize_list:奖品列表
+        :param field_name:字段名称
         :return: 中奖的奖品
         :last_editors: HuangJianYi
         """
@@ -32,18 +33,19 @@ class FrameBaseModel():
         for prize in prize_list:
             current_prize = prize
             current_prize["start_probability"] = init_value
-            current_prize["end_probability"] = init_value + float(prize["chance"])
+            current_prize["end_probability"] = init_value + float(prize[field_name])
             probability_list.append(current_prize)
-            init_value = init_value + float(prize["chance"])
+            init_value = init_value + float(prize[field_name])
         prize_index = random.uniform(0.00, init_value)
         for prize in probability_list:
             if (prize["start_probability"] <= prize_index and prize_index < prize["end_probability"]):
                 return prize
 
-    def lottery_algorithm_probability(self, prize_list):
+    def lottery_algorithm_probability(self, prize_list, field_name="probability"):
         """
         :description: 抽奖算法（权重）
         :param prize_list:奖品列表
+        :param field_name:字段名称
         :return: 中奖的奖品
         :last_editors: HuangJianYi
         """
@@ -52,9 +54,9 @@ class FrameBaseModel():
         for prize in prize_list:
             current_prize = prize
             current_prize["start_probability"] = init_value
-            current_prize["end_probability"] = init_value + prize["probability"]
+            current_prize["end_probability"] = init_value + prize[field_name]
             probability_list.append(current_prize)
-            init_value = init_value + prize["probability"]
+            init_value = init_value + prize[field_name]
         prize_index = random.randint(0, init_value - 1)
         for prize in probability_list:
             if (prize["start_probability"] <= prize_index and prize_index < prize["end_probability"]):
@@ -80,7 +82,7 @@ class FrameBaseModel():
             "TRADE_FINISHED"
         ]
         return status
-    
+
     def refund_status(self):
         """
         :description: 给予奖励的子订单退款状态
@@ -119,7 +121,7 @@ class FrameBaseModel():
             return "已退款"
         else:
             return "交易成功"
-            
+
     def business_process_executing(self,app_id,act_id,module_id,user_id,login_token,handler_name,check_new_user=False,check_user_nick=True,continue_request_expire=5,acquire_lock_name="",request_limit_num=0,request_limit_time=1):
         """
         :description: 业务执行前事件,核心业务如抽奖、做任务需要调用当前方法
@@ -139,13 +141,13 @@ class FrameBaseModel():
         :last_editors: HuangJianYi
         """
         invoke_result_data = InvokeResultData()
-    
+
         if not act_id or not user_id or not login_token or not handler_name:
             invoke_result_data.success = False
             invoke_result_data.error_code = "参数不能为空或等于0"
             invoke_result_data.error_message = f""
             return invoke_result_data
-        
+
         #请求太频繁限制
         if continue_request_expire > 0:
             if SevenHelper.is_continue_request(f"request_business_executing:{handler_name}_{act_id}_{module_id}_{user_id}",expire=continue_request_expire*1000) == True:
@@ -228,10 +230,10 @@ class FrameBaseModel():
             invoke_result_data.error_message = "账号异常,请联系客服处理"
             return invoke_result_data
         if check_new_user == True and user_info_dict["is_new"] == 0:
-                invoke_result_data.success = False
-                invoke_result_data.error_code = "error"
-                invoke_result_data.error_message = "不是新用户"
-                return invoke_result_data
+            invoke_result_data.success = False
+            invoke_result_data.error_code = "error"
+            invoke_result_data.error_message = "不是新用户"
+            return invoke_result_data
         if check_user_nick == True:
             if not user_info_dict["user_nick"]:
                 invoke_result_data.success = False
@@ -239,10 +241,10 @@ class FrameBaseModel():
                 invoke_result_data.error_message = "对不起,请先授权"
                 return invoke_result_data
         if user_info_dict["login_token"] != login_token:
-             invoke_result_data.success = False
-             invoke_result_data.error_code = "error"
-             invoke_result_data.error_message = "已在另一台设备登录,无法操作"
-             return invoke_result_data
+            invoke_result_data.success = False
+            invoke_result_data.error_code = "error"
+            invoke_result_data.error_message = "已在另一台设备登录,无法操作"
+            return invoke_result_data
         #分布式锁名称存在才进行校验
         identifier = ""
         if acquire_lock_name:
@@ -260,7 +262,7 @@ class FrameBaseModel():
         invoke_result_data.data["identifier"] = identifier
         invoke_result_data.data["request_queue_name"] = request_queue_name
         return invoke_result_data
-    
+
     def business_process_executed(self,act_id,module_id,user_id,handler_name,acquire_lock_name="",identifier="",request_queue_name=""):
         """
         :description: 业务执行后事件，调用了业务执行前事件需要调用当前方法
@@ -279,12 +281,3 @@ class FrameBaseModel():
             SevenHelper.redis_release_lock(acquire_lock_name,identifier)
         if request_queue_name:
             SevenHelper.redis_lpop(request_queue_name)
-        
-
-
-        
-    
-    
-
-    
-        
\ No newline at end of file
