@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-09 09:24:43
-@LastEditTime: 2021-12-23 17:37:38
+@LastEditTime: 2021-12-30 11:51:21
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -122,8 +122,7 @@ class OrderBaseModel(FrameBaseModel):
             prize_roster_model = PrizeRosterModel(context=self.context)
             if page_list and len(page_list)>0:
                 order_no_list = [str(i['order_no']) for i in page_list]
-                order_nos = ",".join(order_no_list)
-                prize_roster_list_dict = prize_roster_model.get_dict_list("order_no in (" + order_nos + ")")
+                prize_roster_list_dict = prize_roster_model.get_dict_list(SevenHelper.get_condition_by_str_list("order_no",order_no_list))
                 for i in range(len(page_list)):
                     roster_list = [prize_roster for prize_roster in prize_roster_list_dict if page_list[i]["order_no"] == prize_roster["order_no"]]
                     page_list[i]["roster_list"] = roster_list
@@ -239,9 +238,12 @@ class OrderBaseModel(FrameBaseModel):
             invoke_result_data.error_code = "error"
             invoke_result_data.error_message ="无效活动,无法导入订单"
             return invoke_result_data
+        prize_order_model = PrizeOrderModel(context=self.context)
+        prize_roster_model = PrizeRosterModel(context=self.context)
         data = []
+        total_num = 0
         if content_type == 1:
-            data = base64.decodebytes(content.encode())
+            data = base64.decodebytes(str(content).encode())
             if not os.path.exists("temp"):
                 os.makedirs("temp")
             path = "temp/" + UUIDHelper.get_uuid() + ".xlsx"
@@ -249,47 +251,62 @@ class OrderBaseModel(FrameBaseModel):
                 buf = bytearray(data)
                 f.write(buf)
             f.close()
+            order_no_index = -1
+            express_no_index = -1
+            express_company_index = -1
+
+            data = ExcelHelper.input(path)
+            data_total = len(data)
+            # 表格头部
+            if data_total > 0:
+                title_list = data[0]
+                if ref_head_name in title_list:
+                    order_no_index = title_list.index(ref_head_name)
+                if "物流单号" in title_list:
+                    express_no_index = title_list.index("物流单号")
+                if "物流公司" in title_list:
+                    express_company_index = title_list.index("物流公司")
+
+            if order_no_index == -1 or express_no_index == -1 or express_company_index == -1:
+                invoke_result_data.success = False
+                invoke_result_data.error_code = "error"
+                invoke_result_data.error_message ="缺少必要字段，无法导入订单"
+                return invoke_result_data
+            # 数据导入
+            for i in range(1, data_total):
+                row = data[i]
+                order_no = row[order_no_index]
+                express_no = row[express_no_index]
+                express_company = row[express_company_index]
+                if order_no and express_no and express_company:
+                    now_datetime = SevenHelper.get_now_datetime()
+                    update_sql = "order_status=1,express_company=%s,express_no=%s,deliver_date=%s"
+                    params = [express_company, express_no, now_datetime, app_id,act_id,order_no]
+                    result = prize_order_model.update_table(update_sql, "app_id=%s and act_id=%s and order_no=%s", params)
+                    if result == True:
+                        prize_roster_model.update_table("logistics_status=1", "app_id=%s and act_id=%s and order_no=%s", [app_id,act_id,order_no])
+                        total_num += 1
+            os.remove(path)
         else:
-            data = SevenHelper.json_loads(content.decode())
-
-        order_no_index = -1
-        express_no_index = -1
-        express_company_index = -1
-
-        data = ExcelHelper.input(path)
-        data_total = len(data)
-        # 表格头部
-        if data_total > 0:
-            title_list = data[0]
-            if ref_head_name in title_list:
-                order_no_index = title_list.index(ref_head_name)
-            if "物流单号" in title_list:
-                express_no_index = title_list.index("物流单号")
-            if "物流公司" in title_list:
-                express_company_index = title_list.index("物流公司")
-
-        if order_no_index == -1 or express_no_index == -1 or express_company_index == -1:
-            invoke_result_data.success = False
-            invoke_result_data.error_code = "error"
-            invoke_result_data.error_message ="缺少必要字段，无法导入订单"
-            return invoke_result_data
-        prize_order_model = PrizeOrderModel(context=self.context)
-        prize_roster_model = PrizeRosterModel(context=self.context)
-        # 数据导入
-        for i in range(1, data_total):
-            row = data[i]
-            order_no = row[order_no_index]
-            express_no = row[express_no_index]
-            express_company = row[express_company_index]
-            if order_no and express_no and express_company:
-                now_datetime = SevenHelper.get_now_datetime()
-                update_sql = "order_status=1,express_company=%s,express_no=%s,deliver_date=%s"
-                params = [express_company, express_no, now_datetime, app_id,act_id,order_no]
-                prize_order_model.update_table(update_sql, "app_id=%s and act_id=%s and order_no=%s", params)
-                prize_roster_model.update_table("logistics_status=1", "app_id=%s and act_id=%s and order_no=%s", [app_id,act_id,order_no])
-
-        os.remove(path)
-
+            data = SevenHelper.json_loads(content)
+            for row in data:
+                order_no = row[ref_head_name]
+                express_no = row['物流单号']
+                express_company = row['物流公司']
+                if order_no and express_no and express_company:
+                    now_datetime = SevenHelper.get_now_datetime()
+                    update_sql = "order_status=1,express_company=%s,express_no=%s,deliver_date=%s"
+                    params = [express_company, express_no, now_datetime, app_id,act_id,order_no]
+                    result = prize_order_model.update_table(update_sql, "app_id=%s and act_id=%s and order_no=%s", params)
+                    if result == True:
+                        prize_roster_model.update_table("logistics_status=1", "app_id=%s and act_id=%s and order_no=%s", [app_id,act_id,order_no])
+                        total_num += 1
+                else:
+                    invoke_result_data.success = False
+                    invoke_result_data.error_code = "error"
+                    invoke_result_data.error_message = "缺少必要字段，无法导入订单"
+                    return invoke_result_data
+        invoke_result_data.data = {"total_num": total_num}
         return invoke_result_data
 
     def get_tao_pay_order_list(self,app_id,act_id,user_id,open_id,nick_name,pay_date_start,pay_date_end,page_size=20,page_index=0,field="*",order_by="pay_date desc",condition="",params=[]):
@@ -760,30 +777,35 @@ class OrderBaseModel(FrameBaseModel):
         page_info = PageInfo(page_index, page_size, total, page_list)
         return page_info
 
-    def get_horseracelamp_list(self,act_id,module_id,is_search_module=False,page_size=30):
+    def get_horseracelamp_list(self, act_id, module_id, is_search_module=False, condition="", params=[], page_size=30):
         """
         :description: 获取跑马灯奖品列表
         :param act_id:活动标识
         :param module_id:活动模块标识
         :param is_search_module:是否查询活动模块
+        :param condition：条件
+        :param params：参数数组
         :param page_size：页大小
         :return list
         :last_editors: HuangJianYi
         """
-        condition = "act_id=%s"
-        params = [act_id]
+        condition_where = ConditionWhere()
+        condition_where.add_condition("act_id=%s")
+        params_list = [act_id]
         if is_search_module == True and module_id:
-            condition+= " and module_id=%s"
-            params.append(module_id)
-        act_prize_list_dict = ActPrizeModel(context=self.context).get_cache_list("act_id=%s and is_prize_notice=0 and is_del=0", params=[act_id],cache_expire=60)
+            condition_where.add_condition("module_id=%s")
+            params_list.append(module_id)
+        if condition:
+            condition_where.add_condition(condition)
+            params_list.extend(params)
+        act_prize_list_dict = ActPrizeModel(context=self.context).get_cache_dict_list("act_id=%s and is_prize_notice=0 and is_del=0", params=[act_id],cache_expire=60)
         if act_prize_list_dict:
             prize_id_list = [str(i["id"]) for i in act_prize_list_dict]
             if len(prize_id_list) > 0:
                 prize_ids = ",".join(prize_id_list)
-                condition += " and prize_id not in (" + prize_ids + ")"
-        condition += f" and create_date>'{TimeHelper.add_hours_by_format_time(hour=-1)}'"
+                condition_where.add_condition("prize_id not in (" + prize_ids + ")")
         prize_roster_model = PrizeRosterModel(context=self.context)
-        prize_roster_list = prize_roster_model.get_cache_dict_list(condition, "", "create_date desc", str(page_size), "user_nick,prize_name,tag_id,module_name", params,cache_expire=60)
+        prize_roster_list = prize_roster_model.get_cache_dict_list(condition_where.to_string(), "", "create_date desc", str(page_size), "user_nick,prize_name,tag_id,module_name", params_list, cache_expire=60)
         total = int(len(prize_roster_list))
         if total == 0:
             prize_roster_list = []
