@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-22 11:10:20
-@LastEditTime: 2021-12-17 11:20:30
+@LastEditTime: 2021-12-29 09:40:59
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -112,11 +112,11 @@ class UserBaseModel(FrameBaseModel):
                 user_info_dict = user_info_model.get_cache_dict(dependency_key=dependency_key,where="act_id=%s and open_id=%s", params=[act_id, open_id])
             else:
                 user_info_dict = user_info_model.get_dict("act_id=%s and open_id=%s", params=[act_id, open_id])
-                
+
         if user_info_dict and user_info_dict["app_id"] != app_id:
             user_info_dict = None
         return user_info_dict
-          
+
     def get_user_list(self, app_id, act_id, page_size=20, page_index=0, user_state=-1, user_id=0, start_date="", end_date="", user_nick="", open_id="", order_by="id desc"):
         """
         :description: 获取用户信息列表
@@ -163,7 +163,7 @@ class UserBaseModel(FrameBaseModel):
         page_list, total = UserInfoModel(context=self.context).get_dict_page_list("*", page_index, page_size, condition, order_by=order_by, params=params)
         page_info = PageInfo(page_index, page_size, total, page_list)
         return page_info
-    
+
     def get_join_member_url(self,access_token,app_key,app_secret,is_log):
         """
         :description: 获取加入会员地址
@@ -176,7 +176,7 @@ class UserBaseModel(FrameBaseModel):
         """
         top_base_model = TopBaseModel(context=self.context)
         return top_base_model.get_join_member_url(access_token,app_key,app_secret,is_log)
-    
+
     def save_user_by_openid(self, app_id, act_id, open_id, user_nick, avatar, union_id=""):
         """
         :description: 获取或更新用户信息（主要用于登录）
@@ -224,7 +224,7 @@ class UserBaseModel(FrameBaseModel):
                 user_account.user_nick = user_nick if user_nick and user_account.user_nick != user_nick else user_account.user_nick
                 user_account.avatar = avatar if avatar and user_account.avatar != avatar else user_account.avatar
                 user_account_model.update_entity(user_account, "user_nick,avatar")
-                
+
             user_info = user_info_model.get_entity("act_id=%s and open_id=%s", params=[act_id, open_id])
             if not user_info:
                 user_info = UserInfo()
@@ -258,14 +258,14 @@ class UserBaseModel(FrameBaseModel):
                 user_info.modify_date = now_datetime
                 user_info.login_token = SevenHelper.get_random(16)
                 user_info_model.update_entity(user_info, "modify_date,login_token,is_new,user_nick,avatar,is_auth")
-                
+
                 self._delete_user_info_cache(user_info.act_id,user_info.id_md5)
-                    
+
         except Exception as ex:
             self.context.logging_link_error("【获取或更新用户信息】" + traceback.format_exc())
         finally:
-                SevenHelper.redis_release_lock(acquire_lock_name, identifier)
-        
+            SevenHelper.redis_release_lock(acquire_lock_name, identifier)
+
         invoke_result_data.data = user_info.__dict__
         return invoke_result_data
 
@@ -309,14 +309,14 @@ class UserBaseModel(FrameBaseModel):
                     invoke_result_data.error_message = "非法操作"
                     return invoke_result_data
                 user_info_dict["is_member_before"] = is_member_before if is_member_before!=-1 else user_info_dict["is_member_before"]
-                user_info_dict["is_favor_before"] = is_favor_before if is_favor_before!=-1 else user_info_dict["is_favor_before"]    
+                user_info_dict["is_favor_before"] = is_favor_before if is_favor_before!=-1 else user_info_dict["is_favor_before"]
                 user_info_dict["user_nick"] = user_nick if user_nick else user_info_dict["user_nick"]
                 user_info_dict["avatar"] = avatar if avatar else user_info_dict["avatar"]
                 user_info_dict["modify_date"] = SevenHelper.get_now_datetime()
                 user_info_model.update_table("user_nick=%s,avatar=%s,modify_date=%s,is_member_before=%s,is_favor_before=%s","id=%s",params=[user_info_dict["user_nick"],user_info_dict["avatar"],user_info_dict["modify_date"],user_info_dict["is_member_before"],user_info_dict["is_favor_before"],user_info_dict["id"]])
-                
+
                 self._delete_user_info_cache(user_info_dict["act_id"],user_info_dict["id_md5"])
-                
+
                 update_sql = ""
                 params = []
                 if user_nick:
@@ -370,7 +370,7 @@ class UserBaseModel(FrameBaseModel):
         user_info.user_state = user_state
         user_info.modify_date = modify_date
         user_info_model.update_entity(user_info, "user_state,relieve_date,modify_date")
-        
+
         self._delete_user_info_cache(user_info.act_id,user_info.id_md5)
 
         return invoke_result_data
@@ -388,7 +388,7 @@ class UserBaseModel(FrameBaseModel):
         db_transaction = DbTransaction(db_config_dict=config.get_value("db_cloudapp"))
         user_info_model = UserInfoModel(db_transaction=db_transaction,context=self.context)
         user_black_model = UserBlackModel(db_transaction=db_transaction, context=self.context)
-        
+
         user_info_dict = self.get_user_info_dict(app_id,act_id,user_id)
         if not user_info_dict:
             invoke_result_data.success = False
@@ -500,7 +500,7 @@ class UserBaseModel(FrameBaseModel):
         user_black_model.update_entity(user_black, "audit_status,reason")
         self._delete_user_black_cache(act_id,user_id)
         return invoke_result_data
-    
+
     def audit_user_black(self,app_id,black_id,audit_status,audit_remark=""):
         """
         :description: 审核黑名单
@@ -529,7 +529,7 @@ class UserBaseModel(FrameBaseModel):
             invoke_result_data.error_code = "error"
             invoke_result_data.error_message = "非法操作"
             return invoke_result_data
-            
+
         user_info_model = UserInfoModel(context=self.context)
         id_md5 = self._get_user_info_id_md5(user_black.act_id, user_black.user_id)
         user_info = user_info_model.get_entity("id_md5=%s",params=[id_md5])
@@ -559,7 +559,7 @@ class UserBaseModel(FrameBaseModel):
             user_info_model.update_entity(user_info, "user_state,modify_date,modify_date")
         elif audit_status == 3:
             user_black_model.update_table(condition, "id=%s", params)
-         
+
         invoke_result_data.data = {"user_info":user_info.__dict__}
         self._delete_user_info_cache(user_info.act_id,user_info.id_md5)
         self._delete_user_black_cache(user_black.act_id, user_black.user_id)
@@ -594,8 +594,8 @@ class UserBaseModel(FrameBaseModel):
             return invoke_result_data
         user_black_model.update_table("audit_remark=%s", "id=%s", [audit_remark,black_id])
         self._delete_user_black_cache(black_info.act_id,black_info.user_id)
-        return invoke_result_data        
-        
+        return invoke_result_data
+
     def get_black_info_dict(self, app_id, act_id, user_id,is_cache=True):
         """
         :description: 获取黑名单单条记录
@@ -619,7 +619,7 @@ class UserBaseModel(FrameBaseModel):
             user_black_dict = user_black_model.get_cache_dict(where=where, params=params,dependency_key=self.get_user_black_dependency_key(act_id,user_id))
         else:
             user_black_dict = user_black_model.get_dict(where, params=params)
-        return user_black_dict       
+        return user_black_dict
 
     def get_black_list(self, app_id, act_id, page_size=20, page_index=0, audit_status=-1, user_id=0, start_date="", end_date="", user_nick="", open_id="", order_by="id desc"):
         """
@@ -731,7 +731,7 @@ class UserBaseModel(FrameBaseModel):
             self.context.logging_link_error("【校验是否拉黑】" + traceback.format_exc())
             result = False
         return result
- 
+
     def get_user_address_list(self, app_id, act_id, user_id,is_cache=True):
         """
         :description: 获取用户地址列表
@@ -750,9 +750,9 @@ class UserBaseModel(FrameBaseModel):
         user_address_list = []
         user_address_model = UserAddressModel(context=self.context)
         if is_cache:
-            user_address_list = user_address_model.get_cache_dict_list(condition, params=params, dependency_key=f"user_address_list:actid_{act_id}_userid_{user_id}")
+            user_address_list = user_address_model.get_cache_dict_list(condition, limit="100", params=params, dependency_key=f"user_address_list:actid_{act_id}_userid_{user_id}")
         else:
-            user_address_list = user_address_model.get_dict_list(condition, params=params)
+            user_address_list = user_address_model.get_dict_list(condition, limit="100", params=params)
 
         return user_address_list
 
@@ -782,7 +782,7 @@ class UserBaseModel(FrameBaseModel):
             invoke_result_data.error_code = "param_error"
             invoke_result_data.error_message = "参数不能为空或等于0"
             return invoke_result_data
-        user_info_dict = self.get_user_info_dict(act_id,user_id,open_id)
+        user_info_dict = self.get_user_info_dict(app_id,act_id,user_id,open_id)
         if not user_info_dict:
             invoke_result_data.success = False
             invoke_result_data.error_code = "error"
@@ -828,10 +828,3 @@ class UserBaseModel(FrameBaseModel):
             user_address_model.add_entity(user_address)
         user_address_model.delete_dependency_key(f"user_address_list:actid_{act_id}_userid_{user_id}")
         return invoke_result_data
-
-
-    
-
-
-
-    
