@@ -2,7 +2,7 @@
 """
 :Author: HuangJianYi
 :Date: 2020-04-16 14:38:22
-@LastEditTime: 2021-12-27 13:49:34
+@LastEditTime: 2021-12-29 15:35:09
 @LastEditors: HuangJianYi
 :Description: 基础路由   业务方可以直接使用语句 handlers.extend(seven_cloudapp_frame.route.seven_cloudapp_frame_route()) 引入
 """
@@ -78,12 +78,14 @@ def seven_cloudapp_frame_route():
         (r"/server/friend_link_list", base_s.FriendLinkListHandler),  #获取友情链接产品互推列表
         (r"/server/send_sms", base_s.SendSmsHandler),  #发短信
         (r"/server/cms_info_list", base_s.CmsInfoListHandler),  #位置信息列表
-        (r"/server/save_cms_info_", base_s.SaveCmsInfoHandler),  #保存位置信息
+        (r"/server/save_cms_info", base_s.SaveCmsInfoHandler),  #保存位置信息
+        (r"/server/get_product_price", base_s.GetProductPriceHandler),  #获取产品价格信息
         (r"/server/app_info", app_s.AppInfoHandler),  #应用信息
         (r"/server/get_app_id", app_s.GetAppIDHandler),  #根据店铺名称返回应用标识 用于GM工具
         (r"/server/instantiate", app_s.InstantiateAppHandler),  #实例化小程序
         (r"/server/version_upgrade", app_s.VersionUpgradeHandler),  #小程序端版本升级
         (r"/server/update_telephone", app_s.UpdateTelephoneHandler),  #更新手机号
+        (r"/server/get_short_url", app_s.GetShortUrlHandler),  #淘宝短链接
         (r"/server/act_type_list", act_s.ActTypeListHandler),  #活动类型列表
         (r"/server/next_progress", act_s.NextProgressHandler),  #活动下一步操作
         (r"/server/add_act_info", act_s.AddActInfoHandler),  #添加活动
